@@ -17,9 +17,9 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING. If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+;; Boston, MA 02110-1301 USA
 
 ;;; Commentary:
 
@@ -29,52 +29,52 @@
 
 (require 'easymenu)
 
-(defconst erc-menu-version "$Revision: 1.20 $"
+(defconst erc-menu-version "$Revision: 1.22 $"
   "ERC menu revision")
 
 (defvar erc-menu-definition
   (list "IRC"
 	["Connect to server..." erc-select t]
-	["Disconnect from server..." erc-quit-server erc-connected]
+	["Disconnect from server..." erc-quit-server erc-server-connected]
 	"-"
 	["List channels..." erc-cmd-LIST
-	 (and erc-connected (fboundp 'erc-cmd-LIST))]
-	["Join channel..." erc-join-channel erc-connected]
-	["Start a query..." erc-cmd-QUERY erc-connected]
+	 (and erc-server-connected (fboundp 'erc-cmd-LIST))]
+	["Join channel..." erc-join-channel erc-server-connected]
+	["Start a query..." erc-cmd-QUERY erc-server-connected]
 	"-"
-        ["List users in channel" erc-channel-names erc-channel-users]
-        ["List channel operators" erc-cmd-OPS erc-channel-users]
+	["List users in channel" erc-channel-names erc-channel-users]
+	["List channel operators" erc-cmd-OPS erc-channel-users]
 	["Input action..." erc-input-action (erc-default-target)]
 	["Set topic..." erc-set-topic
 	 (and (and (erc-default-target) (not (erc-query-buffer-p)))
-	      (or (not (member "t" channel-modes))
+	      (or (not (member "t" erc-channel-modes))
 		  (erc-channel-user-op-p (erc-current-nick))))]
 	(list "Channel modes"
 	      ["Change mode..." erc-insert-mode-command
-               (erc-channel-user-op-p (erc-current-nick))]
+	       (erc-channel-user-op-p (erc-current-nick))]
 	      ["No external send" (erc-toggle-channel-mode "n")
-               :active (erc-channel-user-op-p (erc-current-nick))
-	       :style toggle :selected (member "n" channel-modes)]
+	       :active (erc-channel-user-op-p (erc-current-nick))
+	       :style toggle :selected (member "n" erc-channel-modes)]
 	      ["Topic set by channel operator" (erc-toggle-channel-mode "t")
-	       :style toggle :selected (member "t" channel-modes)
-               :active (erc-channel-user-op-p (erc-current-nick))]
+	       :style toggle :selected (member "t" erc-channel-modes)
+	       :active (erc-channel-user-op-p (erc-current-nick))]
 	      ["Invite only" (erc-toggle-channel-mode "i")
-	       :style toggle :selected (member "i" channel-modes)
-               :active (erc-channel-user-op-p (erc-current-nick))]
+	       :style toggle :selected (member "i" erc-channel-modes)
+	       :active (erc-channel-user-op-p (erc-current-nick))]
 	      ["Private" (erc-toggle-channel-mode "p")
-	       :style toggle :selected (member "p" channel-modes)
-               :active (erc-channel-user-op-p (erc-current-nick))]
+	       :style toggle :selected (member "p" erc-channel-modes)
+	       :active (erc-channel-user-op-p (erc-current-nick))]
 	      ["Secret" (erc-toggle-channel-mode "s")
-	       :style toggle :selected (member "s" channel-modes)
-               :active (erc-channel-user-op-p (erc-current-nick))]
+	       :style toggle :selected (member "s" erc-channel-modes)
+	       :active (erc-channel-user-op-p (erc-current-nick))]
 	      ["Moderated" (erc-toggle-channel-mode "m")
-	       :style toggle :selected (member "m" channel-modes)
-               :active (erc-channel-user-op-p (erc-current-nick))]
+	       :style toggle :selected (member "m" erc-channel-modes)
+	       :active (erc-channel-user-op-p (erc-current-nick))]
 	      ["Set a limit..." erc-set-channel-limit
-               (erc-channel-user-op-p (erc-current-nick))]
+	       (erc-channel-user-op-p (erc-current-nick))]
 	      ["Set a key..." erc-set-channel-key
-               (erc-channel-user-op-p (erc-current-nick))])
-        ["Leave this channel..." erc-part-from-channel erc-channel-users]
+	       (erc-channel-user-op-p (erc-current-nick))])
+	["Leave this channel..." erc-part-from-channel erc-channel-users]
 	"-"
 	(list "Pals, fools and other keywords"
 	      ["Add pal..." erc-add-pal]
@@ -88,9 +88,10 @@
 	"-"
 	(list "IRC services"
 	      ["Identify to NickServ..." erc-nickserv-identify
-	       (and erc-connected (functionp 'erc-nickserv-identify))])
+	       (and erc-server-connected (functionp 'erc-nickserv-identify))])
 	"-"
-	["Save buffer in log" erc-save-buffer-in-logs (fboundp 'erc-save-buffer-in-logs)]
+	["Save buffer in log" erc-save-buffer-in-logs
+	 (fboundp 'erc-save-buffer-in-logs)]
 	["Truncate buffer" erc-truncate-buffer (fboundp 'erc-truncate-buffer)]
 	"-"
 	["Customize ERC" (customize-group 'erc) t]
@@ -106,7 +107,8 @@
 
      ;; for some reason the menu isn't automatically added to the menu bar
      (when (featurep 'xemacs)
-       (add-hook 'erc-mode-hook (lambda () (easy-menu-add erc-menu erc-mode-map))))))
+       (add-hook 'erc-mode-hook
+		 (lambda () (easy-menu-add erc-menu erc-mode-map))))))
 
 (provide 'erc-menu)
 
@@ -115,5 +117,4 @@
 ;; Local Variables:
 ;; indent-tabs-mode: t
 ;; tab-width: 8
-;; standard-indent: 4
 ;; End:
